==> kwordquiz-18.07.80.tar.xz: kwordquiz-18.07.80/src/kwqtutorprefs.h <==
/***************************************************************************
                             kwqtutorprefs.h
                             -------------------

    copyright            : (C) 2010by Peter Hedlund
    email                : peter.hedlund@kdemail.net

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KWQTUTORPREFS_H
#define KWQTUTORPREFS_H

#include <KActionCollection>
#include <KConfigDialog>
#include <KShortcutsEditor>

class KConfigSkeleton;

/**
  *@author Peter Hedlund
*/

class PrefTutor;

class KWQTutorPrefs : public KConfigDialog
{
  Q_OBJECT
public:
  KWQTutorPrefs(QWidget *parent, const QString & name, KConfigSkeleton *config,
		KActionCollection *actionCollection);

protected slots:
  void updateSettings() Q_DECL_OVERRIDE;
  void updateWidgetsDefault() Q_DECL_OVERRIDE;
  void slotEnableApplyButton();

protected:
  bool hasChanged() Q_DECL_OVERRIDE;

private:
  PrefTutor *m_prefTutor;
  KConfigSkeleton * m_config;
  KShortcutsEditor* m_shortcutsWidget;
};

#endif

==> kwordquiz-18.12.3.tar.xz: kwordquiz-18.12.3/src/kwqtutorprefs.h <==
/***************************************************************************
                             kwqtutorprefs.h
                             -------------------

    copyright            : (C) 2010by Peter Hedlund
    email                : peter.hedlund@kdemail.net

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KWQTUTORPREFS_H
#define KWQTUTORPREFS_H

#include <KActionCollection>
#include <KConfigDialog>
#include <KShortcutsEditor>

class KConfigSkeleton;

/**
  *@author Peter Hedlund
*/

class PrefTutor;

class KWQTutorPrefs : public KConfigDialog
{
  Q_OBJECT
public:
  KWQTutorPrefs(QWidget *parent, const QString & name, KConfigSkeleton *config,
		KActionCollection *actionCollection);

protected slots:
  void updateSettings() override;
  void updateWidgetsDefault() override;
  void slotEnableApplyButton();

protected:
  bool hasChanged() override;

private:
  PrefTutor *m_prefTutor;
  KConfigSkeleton * m_config;
  KShortcutsEditor* m_shortcutsWidget;
};

#endif
